
##### SET TO LOCATION OF DATA FILES. OUTPUTS WILL ALSO SAVE HERE #####

filepath <- "C:/Users/dansh/Documents/"

######################################################################


### imports

library(readxl)
library(wrapr)
wiod_us_2020 <- read_excel(paste(filepath,"wiod_us.xlsx",sep=""), sheet = "wiod_us_2020")
agestructure_us_2020 <- read_excel(paste(filepath,"wiod_us.xlsx",sep=""), sheet = "agestructure_us_2020")
inv_us_2020 <- read_excel(paste(filepath,"wiod_us.xlsx",sep=""), sheet = "inv_us_2020")
wiod_us_2030 <- read_excel(paste(filepath,"wiod_us.xlsx",sep=""), sheet = "wiod_us_2030")
agestructure_us_2030 <- read_excel(paste(filepath,"wiod_us.xlsx",sep=""), sheet = "agestructure_us_2030")
inv_us_2030 <- read_excel(paste(filepath,"wiod_us.xlsx",sep=""), sheet = "inv_us_2030")
human_capital_distributions <- read_excel(paste(filepath,"human_capital_distributions.xlsx",sep=""), sheet = "US")


for (m in c(3:4)){  #scenario (see below)
  
  for (mm in c(1:1000)){  #simulations of each scenario
    
    
    #################### INITIALISATION ####################
    
    
    t <- 1  #year
    
    
    ### set start and end year
    
    if(m == 1){  #PRS2020
      yearstart <- 2020
      target <- 2050
    }else if(m == 2){  #PRS2030
      yearstart <- 2030
      target <- 2050
    }else if(m == 3){  #ARS2020
      yearstart <- 2020
      target <- 2050
    }else if(m == 4){  #ARS2030
      yearstart <- 2030
      target <- 2050
    }
    simlength <- 2100-yearstart  #total number of years model runs for
    
    
    ### set up discounting
    
    #produced
    produced_discountrate <- 0.06  #discount rate (%)
    discountp <- rep(1,simlength)  #discount function
    for(s in c(2:length(discountp))){
      discountp[s] <- discountp[s-1] * (1 - produced_discountrate)
    }
    
    #human
    human_discountrate <- 0.015  #discount rate (%)
    discounth <- rep(1,simlength)  #discount function
    for(s in c(2:length(discounth))){
      discounth[s] <- discounth[s-1] * (1 - human_discountrate)
    }
    
    
    ### generate emissions target trajectory
    
    t_H <- (target - yearstart) + 1  #years to net-zero
    if(yearstart == 2020){  #emissions rate in starting year (excluding LUC)
      t_E0 <- sum(wiod_us_2020$Emissions)/(3.67*10^6)
    }else if(yearstart == 2030){
      t_E0 <- sum(wiod_us_2030$Emissions)/(3.67*10^6)
    }
    t_t <- c(0:t_H)  #time from starting year
    t_m <- t_E0/t_H  #linear rate of decline to get to zero in H years
    t_E <- t_E0 - t_m*t_t;  #linear decline in emissions to zero in H years
    t_SE <- sum(t_E)  #cumulative emissions at net zero
    if(yearstart == 2020){  #create target line of appropriate length
      Eu_target <- c((cumsum(t_E)),rep(max((cumsum(t_E))),39))
    }else if(yearstart == 2030){
      Eu_target <- c((cumsum(t_E)),rep(max((cumsum(t_E))),49))
    }
    
    
    ### extract relevant capital and emissions data from database
    
    if(yearstart == 2020){
      kp_sect <- wiod_us_2020$ProducedCapital  #produced capital stock, M$
      kh_sect <- wiod_us_2020$HumanCapital  #human capital stock, M$
      u_sect <- unlist(wiod_us_2020$Emissions)/(3.67*10^6)  #emissions by sector, GtC (coverted from kt CO2)
      i_sect <- wiod_us_2020$EmissionIntensity  #emissions intensity, kt CO2/M$
      a_sect <- unlist(wiod_us_2020$Productivity)  #productivity
      dt <- 1.12
    }else if(yearstart == 2030){
      kp_sect <- wiod_us_2030$ProducedCapital  #produced capital stock, M$
      kh_sect <- wiod_us_2030$HumanCapital  #human capital stock, M$
      u_sect <- unlist(wiod_us_2030$Emissions)/(3.67*10^6)  #emissions by sector, GtC (coverted from kt CO2)
      i_sect <- wiod_us_2030$EmissionIntensity  #emissions intensity, kt CO2/M$
      a_sect <- unlist(wiod_us_2030$Productivity)  #productivity
      dt <- 1.32
    }
    Tp_sect <- unlist(wiod_us_2020$ProdLifetime)  #produced capital lifetimes, years
    Th_sect <- unlist(wiod_us_2020$HumanLifetime)  #human capital lifetimes, years
    
    
    ### add uncertainties from 2nd simulation onwards (randomised within 5-95 percentiles)
    
    if(mm > 2){  
      #produced capital in each sector, +/- 15.817% (st.dev. of capital estimates)
      kp_mc <- sum(kp_sect) * ((1 - 0.15817) + (runif(1) * 2 * 0.15817))  #new total produced capital
      kp_sect <- kp_sect * (kp_mc / sum(kp_sect))  #scale sectoral produced capital to new total
      
      #human capital in each sector, +/- 15.817%
      kh_mc <- sum(kh_sect) * ((1 - 0.15817) + (runif(1) * 2 * 0.15817))  #new total human capital
      kh_sect <- kh_sect * (kh_mc / sum(kh_sect))  #scale sectoral human capital to new total
      
      #emissions intensities, +/- 5% (based on GCP)
      i_sect <- (i_sect * 0.95) + ((runif(1) * 0.1) * i_sect)
      
      #GDP, +/- 15.274% (st.dev. of GDP estimates)
      a_sect <- a_sect * ((1 - 0.15274) + (runif(1) * 2 * 0.15274))
      # yp_sect <- ((kp_sect * a_sect) * 0.8473) + ((runif(1) * 0.3055) * (kp_sect * a_sect))  #produced GDP in each sector
      # yh_sect <- ((kp_sect * a_sect) * 0.8473) + ((runif(1) * 0.3055) * (kp_sect * a_sect))  #human GDP in each sector
    }
    
    
    ### sum capital
    
    k_sect <- kp_sect + kh_sect  #total capital in each sector
    kp <- sum(kp_sect)  #total produced/produced capital
    kh <- sum(kh_sect)  #total human capital
    k <- kp + kh  #total capital
    
    #create tables of annual capital by sector 
    kp_secttable <- data.frame(kp_sect)  #produced capital table
    kh_secttable <- data.frame(kh_sect)  #human capital table
    k_secttable <- data.frame(k_sect)  #total capital table
    sect_names <- unlist(wiod_us_2020$sector)  #names of sectors
    
    
    ### set up produced capital age structure
    
    #create table, extract 2020 age structure from database
    if(yearstart == 2020){  
      kpA <- agestructure_us_2020[-c(1:2)]
    }else if(yearstart == 2030){
      kpA <- agestructure_us_2030[-c(1:2)]
    }
    
    #add column names
    colnames(kpA) <- c(1:ncol(kpA))  
    
    #scale age structure to reflect capital uncertainty (see earlier)
    if(mm > 2){  
      kpA <- kpA * (kp_mc / sum(kpA))  
    }
    
    
    ### set up human capital age structure
    
    #extract normalised region-wide distribution
    khA_sect <- as.numeric(human_capital_distributions$Capvalue[-1])/100
    
    #create table, scale distribution to sector totals
    for(sect in c(1:length(kh_sect))){
      if(sect==1){
        khA <- t(data.frame(khA_sect * kh_sect[sect]))
      }else{
        khA <- rbind(khA,khA_sect * kh_sect[sect])
      }
    }
    
    #add column names
    colnames(khA) <- c(1:ncol(khA))  
    
    #scale age structure to reflect capital uncertainty (see earlier)
    if(mm > 2){
      khA <- khA * (kh_mc/sum(khA))
    }
    
    #set up table recording evolution of human capital ages for fig. 3ii
    khA_ages <- data.frame(colSums(khA))
    
    
    ### set up produced capital depreciation
    
    #create sectoral survival functions based on timescale
    f <- data.frame()
    for(sect in c(1:length(kp_sect))){
      for(s in c(1:200)){
        if(Tp_sect[sect] > 0){
          f[sect,s] <- (9^9) * (factorial(8)^(-1)) * (Tp_sect[sect]^(-9)) * (s^8) * (exp(-(9*s)/Tp_sect[sect]))
        }else{
          f[sect,s] <- 0
        }
      }
    }
    
    #extract historical investment in produced capital from database
    if(yearstart == 2020){ 
      inv <- inv_us_2020[-c(1:2)]
    }else if(yearstart == 2030){
      inv <- inv_us_2030[-c(1:2)]
    }
    
    #scale investment to reflect capital uncertainty
    inv <- inv * (sum(kpA[1]) / sum(inv[1]))
    
    
    ### set up human capital depreciation
    
    #extract retirement distribution
    dhA_normalised <- as.numeric(human_capital_distributions$Retirements[-1])/100  #extract distribution of retirements
    
    #scale to sectors
    for(sect in c(1:length(kh_sect))){
      if(sect==1){
        dhA <- t(data.frame(dhA_normalised * kh_sect[sect]))
      }else{
        dhA <- rbind(dhA,dhA_normalised * kh_sect[sect])
      }
    }
    
    
    ### set up GDP and emissions
    
    yp_sect <- kp_sect * a_sect  #produced GDP by sector
    yh_sect <- kh_sect * a_sect  #human GDP by sector
    y_sect <- yp_sect + yh_sect  #total GDP by sector
    yp <- sum(yp_sect)  #total produced GDP
    yh <- sum(yh_sect)  #total human GDP
    y <- yp + yh  #total GDP
    
    u <- rep(0,simlength)  #annual industrial emissions, GtC
    u[1] <- sum(u_sect)  #2020 emissions from database
    u_secttable <- data.frame(u_sect)  #create table of annual sectoral emissions
    Eu <- u  #cumulative emissions from start year, GtC
    
    
    ### asset scrapping variables
    
    cap <- 1000  #total emissions allowed to be scrapped in any year
    nextu <- 0  #next year's simulated emissions
    nextEu <- rep(0,simlength)  #next year's simulated cumulative emissions
    u_gap <- rep(0,simlength)  #gap between next year's emissions and target line
    u_toscrap <- rep(0,simlength)  #target to scrap
    kp_scrapped <- rep(0,simlength)  #total produced capital removed from simulation annually
    kh_scrapped <- rep(0,simlength)  #total human capital removed from simulation annually
    k_scrapped <- rep(0,simlength)  #total capital removed from simulation annually
    u_scrapped <- rep(0,simlength)  #total annual emissions removed by scrapping capital
    sect_scrapped <- rep(0,length(wiod_us_2020$sector))  #total capital removed from each sector
    
    #create table of scrapped capital
    scrapped_table <- data.frame(1,sect_names[1],0,0,0,0,"Produced",0,0,0,0,0,stringsAsFactors=FALSE)
    colnames(scrapped_table) <- c("Sect. no.","Sector","Year","Capital (present value)","Capital (discounted)","Type","Age","Lifetime","Life left","Prop. life left","Emissions intensity","Next year emissions")
    scrapped_table[1] <- as.numeric(unlist(scrapped_table[1]))  #convert sector no. column to numeric type
    scrapped_table[4] <- as.numeric(unlist(scrapped_table[4]))  #convert capital column to numeric type
    scrapped_table[5] <- as.numeric(unlist(scrapped_table[5]))  #convert discounted capital column to numeric type
    scrapped_table[12] <- as.numeric(unlist(scrapped_table[12]))  #convert emissions column to numeric type
    
    
    #################### END INITIALISATION ####################
    
    
    
    #################### BEGIN SIMULATION ####################
    
    
    for (t in c(2:simlength)){
      
      ### production
      
      yp_sect <- kp_sect * a_sect #produced GDP by sector
      yh_sect <- kh_sect * a_sect #human GDP by sector
      y_sect <- yp_sect + yh_sect #total GDP by sector
      yp[t] <- sum(yp_sect) #total produced GDP
      yh[t] <- sum(yh_sect) #total human GDP
      y[t] <- yp[t] + yh[t] #total GDP 
      
      
      ### emissions
      
      u_sect <- sum((y_sect * i_sect) / (3.67*10^6))  #sectoral emissions = GDP * emissions intensity
      u[t] <- sum(u_sect)  #total emissions
      if(t > 1){
        Eu[t] <- Eu[t-1] + u[t]  #add to cumulative emissions
      }else{
        Eu[1] <- u[t]
      }
      
      u_secttable <- cbind(u_secttable,u_sect)  #add emissions to annual tables      
      
      
      ### capital depreciation
      
      #produced capital
      for(sect in c(1:nrow(kpA))){  #each sector
        if(sum(kpA[sect,]) > 0){  #if sector isn't empty
          kpA[sect,] <- kpA[sect,] - (inv[sect,] * f[sect,c(1:length(inv[sect,]))])  #k = last year's k - (initial investment * survival function)
        }
        for(s in c(1:ncol(kpA))){  #check no values have gone below 0
          if(kpA[sect,s] < 0){  
            kpA[sect,s] <- 0  #assign 0 to any that have
          } 
        }
      }
      kpA <- cbind(rep(0,nrow(kpA)),kpA)  #age produced capital one year
      colnames(kpA) <- c(1:ncol(kpA))  #rename columns
      inv <- cbind(rep(0,nrow(inv)),inv)  #age initial investment one year
      f <- cbind(f,rep(0,nrow(f)))  #age survival function one year
      
      #human capital
      for(s in c(1:nrow(khA))){  #each sector
        nextkhA <- unlist(khA[s,])  #extract human capital
        nextkhA <- nextkhA - dhA[s,]  #apply survival function
        nextkhA[nextkhA < 0] <- 0  #if human capital is less than zero, set to zero
        nextkhA <- c(0,nextkhA[-80])  #age human capital one year
        khA[s,] <- nextkhA  #re-insert human capital
      }
      
      #re-sum capital
      kp_sect <- unname(rowSums(kpA))
      kh_sect <- unname(rowSums(khA))
      k_sect <- kp_sect + kh_sect
      kp[t] <- sum(kp_sect)  
      kh[t] <- sum(kh_sect)  
      k[t] <- kp[t] + kh[t]
      
      
      
      
      #################### ASSET STRANDING ####################
      
      if (m > 2 & t > 0 & t < ((target-yearstart)+2)) {
        
        ### calculate stranding target
        
        #project next year's emissions
        nexty_kpA <- kpA * a_sect  #next year's produced GDP
        nexty_khA <- khA * a_sect  #next year's human GDP
        nextu_kpA <- (nexty_kpA * i_sect) / (3.67*10^6)  #next year's produced emissions
        nextu_khA <- (nexty_khA * i_sect) / (3.67*10^6)  #next year's human emissions
        nextu[t] <- sum(nextu_kpA) + sum(nextu_khA)  #next year's total emissions
        nextEu[t] <- Eu[t] + nextu[t]  #next year's cumulative emissions
        
        #amount of capital to be removed
        u_gap[t] <- nextEu[t] - Eu_target[t+1]  #removals needed = projected emissions - target emissions
        u_toscrap[t] <- min(u_gap[t],cap)  #introduce stranding cap if necessary
        
        #failsafe: in final year, scrap any capital remaining
        if(t == (target-yearstart)+1){
          u_toscrap[t] <- nextu[t]
        }
        
        
        ### rank capital in stranding priority
        
        #create table
        ranked_k <- data.frame(matrix(0, nrow = ((nrow(kpA)*ncol(kpA))+(nrow(khA)*ncol(khA))), ncol = 12))
        colnames(ranked_k) <- c("Sect. no.","Sector","Rank","Capital (present value)","Capital (discounted)","Type","Age","Lifetime","Life left","Prop. life left","Emissions intensity","Next year emissions")
        ranked_k_row <- 0
        
        #produced
        for(s in c(1:nrow(kpA))){  #each sector
          for(x in c(1:ncol(kpA))){  #each age
            if(kpA[s,x] > 0){  #add produced capital
              
              #calculate rank
              rank <- i_sect[s] * (x/Tp_sect[s])  #rank = emissions intensity * lifetime elapsed
              
              #add to ranked_k
              ranked_k_row <- ranked_k_row + 1
              ranked_k[ranked_k_row,] <- data.frame(s,sect_names[s],rank,kpA[s,x],(kpA[s,x]*discountp[t]),"Produced",x,Tp_sect[s],Tp_sect[s]-x,1-(x/Tp_sect[s]),i_sect[s],nextu_kpA[s,x])
            }
          }
        }
        
        #human
        for(s in c(1:nrow(khA))){  #each sector
          for(x in c(1:ncol(khA))){  #each age
            if(khA[s,x] > 0){  #add human capital
              
              #calculate rank
              rank <- i_sect[s] * (x/58)  #rank = emissions intensity * lifetime elapsed
              
              #add to ranked_k
              ranked_k_row <- ranked_k_row + 1
              ranked_k[ranked_k_row,] <- data.frame(s,sect_names[s],rank,khA[s,x],(khA[s,x]*discounth[t]),"Human",x,58,58-x,1-(x/58),i_sect[s],nextu_khA[s,x])
            }
          }
        }
        
        #order table by rank (and fix some data types)
        ranked_k[1] <- as.numeric(unlist(ranked_k[1]))  #convert sector no. column to numeric type
        ranked_k[3] <- as.numeric(unlist(ranked_k[3]))  #convert rank column to numeric type
        ranked_k[4] <- as.numeric(unlist(ranked_k[4]))  #convert capital column to numeric type
        ranked_k[5] <- as.numeric(unlist(ranked_k[5]))  #convert discounted capital column to numeric type
        ranked_k[7] <- as.numeric(unlist(ranked_k[7]))  #convert age column to numeric type
        ranked_k[8] <- as.numeric(unlist(ranked_k[8]))  #convert lifetime column to numeric type
        ranked_k[12] <- as.numeric(unlist(ranked_k[12]))  #convert emissions column to numeric type
        ranked_k <- ranked_k[orderv(ranked_k[3],decreasing=T),]  #order by rank
        
        
        ### remove capital until target is met
        
        r <- 1 #rank
        #until enough capital is scrapped to = u_gap...
        while(u_scrapped[t] < u_toscrap[t] & u_scrapped[t] < sum(ranked_k$`Next year emissions`) & r <= nrow(ranked_k) & is.na(sum(khA)) == FALSE){
          #and as long as there is still capital left...
          if(is.na(sum(khA)) == FALSE){
            #if the row has more next_u than remaining u_gap...
            if((u_toscrap[t] - u_scrapped[t]) >= ranked_k$`Next year emissions`[r]){
              
              u_scrapped[t] <- u_scrapped[t] + ranked_k$`Next year emissions`[r]  #add to u_scrapped
              
              #human capital
              if(ranked_k$Type[r] == "Human"){
                kh_scrapped[t] <- kh_scrapped[t] + ranked_k$`Capital (present value)`[r]  #add to kh_scrapped
                khA[ranked_k$`Sect. no.`[r],ranked_k$Age[r]] <- 0  #remove from khA
                
                #produced capital
              }else if(ranked_k$Type[r] == "Produced"){
                kp_scrapped[t] <- kp_scrapped[t] + ranked_k$`Capital (present value)`[r]  #add to kp_scrapped
                kpA[ranked_k$`Sect. no.`[r],ranked_k$Age[r]] <- 0  #remove from kpA
              }
              
              sect_scrapped[ranked_k$`Sect. no.`[r]] <- sect_scrapped[ranked_k$`Sect. no.`[r]] + ranked_k$`Capital (present value)`[r]
              scrapped_table <- rbind(scrapped_table,unlist(ranked_k[r,]))  #add to scrapped_table
              scrapped_table[nrow(scrapped_table),3] <- t+(yearstart-1)  #insert year in place of rank
              
              #if only part of the row's capital is needed...
            }else{
              
              prop <- (u_toscrap[t] - u_scrapped[t])/ranked_k$`Next year emissions`[r] #proportion of the row to be scrapped
              u_scrapped[t] <- u_scrapped[t] + (ranked_k$`Next year emissions`[r] * prop)  #add to u_scrapped
              
              #human capital
              if(ranked_k$Type[r] == "Human"){
                kh_scrapped[t] <- kh_scrapped[t] + (ranked_k$`Capital (present value)`[r] * prop)  #add to kh_scrapped
                khA[ranked_k$`Sect. no.`[r],ranked_k$Age[r]] <- khA[ranked_k$`Sect. no.`[r],ranked_k$Age[r]] - (ranked_k$`Capital (present value)`[r] * prop) #remove from khA
                
                #produced capital
              }else if(ranked_k$Type[r] == "Produced"){
                kp_scrapped[t] <- kp_scrapped[t] + (ranked_k$`Capital (present value)`[r] * prop)  #add to kp_scrapped
                kpA[ranked_k$`Sect. no.`[r],ranked_k$Age[r]] <- kpA[ranked_k$`Sect. no.`[r],ranked_k$Age[r]] - (ranked_k$`Capital (present value)`[r] * prop) #remove from kpA
              }
              
              sect_scrapped[ranked_k$`Sect. no.`[r]] <- sect_scrapped[ranked_k$`Sect. no.`[r]] + (ranked_k$`Capital (present value)`[r] * prop)
              scrapped_table <- rbind(scrapped_table,unlist(ranked_k[r,]))  #add to scrapped_table
              scrapped_table[nrow(scrapped_table),3] <- t+(yearstart-1)  #insert year in place of rank
              scrapped_table[nrow(scrapped_table),4] <- as.numeric(scrapped_table[nrow(scrapped_table),4]) * prop
              scrapped_table[nrow(scrapped_table),5] <- as.numeric(scrapped_table[nrow(scrapped_table),5]) * prop
              scrapped_table[nrow(scrapped_table),12] <- as.numeric(scrapped_table[nrow(scrapped_table),12]) * prop
              
            }
          }else{
            break  #if there is no capital left, stop stranding
          }
          r <- r + 1
          k_scrapped[t] <- kh_scrapped[t] + kp_scrapped[t]
        }
        
        if(is.na(sum(khA)) == TRUE){
          next  #if there is no capital left, stop this simulation
        }
        
        #re-sum capital
        kp_sect <- unname(rowSums(kpA))
        kh_sect <- unname(rowSums(khA))
        k_sect <- kp_sect + kh_sect
        kp[t] <- sum(kp_sect)
        kh[t] <- sum(kh_sect)
        k[t] <- kp[t] + kh[t]
        
        #add age totals to annual tally
        khA_ages <- cbind(khA_ages,colSums(khA))  
        
        #add capital to annual tables
        kp_secttable <- cbind(kp_secttable,kp_sect)  
        kh_secttable <- cbind(kh_secttable,kh_sect)
        k_secttable <- cbind(k_secttable,k_sect)
        
      }  #end asset stranding
      
      
      #################### END ASSET STRANDING ####################
      
      
    }  #next year
    
    
    ### discounting
    
    #multiply scrapped totals by discount function
    kp_scrapped_discounted <- kp_scrapped * discountp
    kh_scrapped_discounted <- kh_scrapped * discounth
    k_scrapped_discounted <- kp_scrapped_discounted + kh_scrapped_discounted
    
    
    #################### OUTPUT ####################
    
    
    if(m == 3 & mm == 1){
      full_output <- t(data.frame(c("start year","target","sim","DISCOUNTED scrapped","min","max","h min","h max","p min","p max","NOT DISCOUNTED scrapped","min","max","h min","h max","p min","p max",c(yearstart,target,mm,round(sum(k_scrapped_discounted)/1000000,3),"-","-","-","-","-","-",round(sum(k_scrapped)/1000000,3),"-","-","-","-","-","-"))))
    }
    
    if(mm == 1){ #1st simulation, set up mc_kscrapped
      
      mc_kscrapped <- sum(k_scrapped)  #total capital scrapped each simulation
      mc_kscrappedtable <- data.frame(k_scrapped)  #table of years capital was scrapped each simulation
      
      mc_kscrapped_discounted <- sum(k_scrapped_discounted)  #total capital scrapped each simulation
      mc_kscrappedtable_discounted <- data.frame(k_scrapped_discounted)  #table of years capital was scrapped each simulation
      
      if(m == 1){
        
        #save capital and emissions for figs. 3i & 3ii
        fig2i_k_2020 <- k/1000000
        fig2i_kp_2020 <- kp/1000000
        fig2i_kh_2020 <- kh/1000000
        fig2i_Eu_2020 <- Eu
        
        khA_ages_2020 <- khA_ages
        
        #save sector capital tables for fig. 3iii
        k_secttable_2020 <- k_secttable
        
      }else if(m == 2){
        
        #save capital and emissions for figs. 3i & 3ii
        fig2i_k_2030 <- k/1000000
        fig2i_kp_2030 <- kp/1000000
        fig2i_kh_2030 <- kh/1000000
        fig2i_Eu_2030 <- Eu
        fig2i_k_2030 <- c(rep(0,10),fig2i_k_2030)
        fig2i_kp_2030 <- c(rep(0,10),fig2i_kp_2030)
        fig2i_kh_2030 <- c(rep(0,10),fig2i_kh_2030)
        fig2i_Eu_2030 <- c(rep(0,10),fig2i_Eu_2030)
        
        khA_ages_2030 <- khA_ages
        
        #save sector capital tables for fig. 3iii
        k_secttable_2030 <- k_secttable
        
      }else if(m == 3){
        
        #save capital and emissions for figs. 3i & 3ii
        fig2i_k_2020_stranding <- k/1000000
        fig2i_kp_2020_stranding <- kp/1000000
        fig2i_kh_2020_stranding <- kh/1000000
        fig2i_Eu_2020_stranding <- Eu
        
        khA_ages_2020_stranding <- khA_ages
        
        #save sector capital tables for fig. 3iii
        k_secttable_2020_stranding <- k_secttable
        
        #set up running totals for scrapped capital
        mc_kscrapped_us_2020 <- sum(k_scrapped)  #total capital scrapped
        mc_kpscrapped_us_2020 <- sum(kp_scrapped)  #produced capital scrapped
        mc_khscrapped_us_2020 <- sum(kh_scrapped)  #human capital scrapped
        mc_kscrappedtable_us_2020 <- data.frame(k_scrapped)  #table of years capital was scrapped
        
        #save highest & lowest scrapped_tables for further analysis
        low_scrappedtable_us_2020 <- scrapped_table
        high_scrappedtable_us_2020 <- scrapped_table
        
        #set up running totals for scrapped capital DISCOUNTED
        mc_kscrapped_us_2020_discounted <- sum(k_scrapped_discounted)  #total capital scrapped
        mc_kpscrapped_us_2020_discounted <- sum(kp_scrapped_discounted)  #produced capital scrapped
        mc_khscrapped_us_2020_discounted <- sum(kh_scrapped_discounted)  #human capital scrapped
        mc_kscrappedtable_us_2020_discounted <- data.frame(k_scrapped_discounted)  #table of years capital was scrapped
        
        #save highest & lowest scrapped_tables for further analysis DISCOUNTED
        low_scrappedtable_us_2020_discounted <- scrapped_table
        high_scrappedtable_us_2020_discounted <- scrapped_table
        
      }else if(m == 4){
        
        #save capital and emissions for figs. 3i & 3ii
        fig2i_k_2030_stranding <- k/1000000
        fig2i_kp_2030_stranding <- kp/1000000
        fig2i_kh_2030_stranding <- kh/1000000
        fig2i_Eu_2030_stranding <- Eu
        fig2i_k_2030_stranding <- c(rep(0,10),fig2i_k_2030_stranding)
        fig2i_kp_2030_stranding <- c(rep(0,10),fig2i_kp_2030_stranding)
        fig2i_kh_2030_stranding <- c(rep(0,10),fig2i_kh_2030_stranding)
        fig2i_Eu_2030_stranding <- c(rep(0,10),fig2i_Eu_2030_stranding)
        
        khA_ages_2030_stranding <- khA_ages
        
        #save sector capital tables for fig. 3iii
        k_secttable_2030_stranding <- k_secttable
        
        #set up running totals for scrapped capital
        mc_kscrapped_us_2030 <- sum(k_scrapped)  #total capital scrapped
        mc_kpscrapped_us_2030 <- sum(kp_scrapped)  #produced capital scrapped
        mc_khscrapped_us_2030 <- sum(kh_scrapped)  #human capital scrapped
        mc_kscrappedtable_us_2030 <- data.frame(k_scrapped)  #table of years capital was scrapped
        
        #save highest & lowest scrapped_tables for further analysis
        low_scrappedtable_us_2030 <- scrapped_table
        high_scrappedtable_us_2030 <- scrapped_table
        
        #set up running totals for scrapped capital DISCOUNTED
        mc_kscrapped_us_2030_discounted <- sum(k_scrapped_discounted)  #total capital scrapped
        mc_kpscrapped_us_2030_discounted <- sum(kp_scrapped_discounted)  #produced capital scrapped
        mc_khscrapped_us_2030_discounted <- sum(kh_scrapped_discounted)  #human capital scrapped
        mc_kscrappedtable_us_2030_discounted <- data.frame(k_scrapped_discounted)  #table of years capital was scrapped
        
        #save highest & lowest scrapped_tables for further analysis DISCOUNTED
        low_scrappedtable_us_2030_discounted <- scrapped_table
        high_scrappedtable_us_2030_discounted <- scrapped_table
        
      }
      
    }else{ #2nd simulation onwards
      
      if(m == 3){
        
        #add total scrapped to running totals 
        mc_kscrapped_us_2020 <- c(mc_kscrapped_us_2020,sum(k_scrapped))  #total capital scrapped
        mc_kpscrapped_us_2020 <- c(mc_kpscrapped_us_2020,sum(kp_scrapped))  #produced capital scrapped
        mc_khscrapped_us_2020 <- c(mc_khscrapped_us_2020,sum(kh_scrapped))  #human capital scrapped
        mc_kscrappedtable_us_2020 <- cbind(mc_kscrappedtable_us_2020,k_scrapped)  #table of years capital was scrapped
        
        #save highest & lowest scrapped_tables for further analysis
        if(sum(k_scrapped) == min(mc_kscrapped_us_2020)){
          low_scrappedtable_us_2020 <- scrapped_table
        }else if(sum(k_scrapped) == max(mc_kscrapped_us_2020)){
          high_scrappedtable_us_2020 <- scrapped_table
        }
        
        #add total scrapped to running totals DISCOUNTED
        mc_kscrapped_us_2020_discounted <- c(mc_kscrapped_us_2020_discounted,sum(k_scrapped_discounted))  #total capital scrapped
        mc_kpscrapped_us_2020_discounted <- c(mc_kpscrapped_us_2020_discounted,sum(kp_scrapped_discounted))  #produced capital scrapped
        mc_khscrapped_us_2020_discounted <- c(mc_khscrapped_us_2020_discounted,sum(kh_scrapped_discounted))  #human capital scrapped
        mc_kscrappedtable_us_2020_discounted <- cbind(mc_kscrappedtable_us_2020_discounted,k_scrapped_discounted)  #table of years capital was scrapped
        
        #save highest & lowest scrapped_tables for further analysis DISCOUNTED
        if(sum(k_scrapped_discounted) == min(mc_kscrapped_us_2020_discounted)){
          low_scrappedtable_us_2020_discounted <- scrapped_table
        }else if(sum(k_scrapped_discounted) == max(mc_kscrapped_us_2020_discounted)){
          high_scrappedtable_us_2020_discounted <- scrapped_table
        }
        
        #outputs
        console <- paste0("scenario = ",yearstart, " ~ ",target," (",m,") / ","sim = ",mm, " / scrapped (discounted) = ",round(sum(k_scrapped_discounted)/1000000,3), " / min = ",round(min(mc_kscrapped_us_2020_discounted)/1000000,3),", max = ",round(max(mc_kscrapped_us_2020_discounted)/1000000,3))
        full_output <- rbind(full_output,c(yearstart,target,mm,round(sum(k_scrapped_discounted)/1000000,3),round(min(mc_kscrapped_us_2020_discounted)/1000000,3),round(max(mc_kscrapped_us_2020_discounted)/1000000,3),round(min(mc_khscrapped_us_2020_discounted)/1000000,3),round(max(mc_khscrapped_us_2020_discounted)/1000000,3),round(min(mc_kpscrapped_us_2020_discounted)/1000000,3),round(max(mc_kpscrapped_us_2020_discounted)/1000000,3),round(sum(k_scrapped)/1000000,3),round(min(mc_kscrapped_us_2020)/1000000,3),round(max(mc_kscrapped_us_2020)/1000000,3),round(min(mc_khscrapped_us_2020)/1000000,3),round(max(mc_khscrapped_us_2020)/1000000,3),round(min(mc_kpscrapped_us_2020)/1000000,3),round(max(mc_kpscrapped_us_2020)/1000000,3)))
        
      }else if(m == 4){
        
        #add total scrapped to running totals
        mc_kscrapped_us_2030 <- c(mc_kscrapped_us_2030,sum(k_scrapped))  #total capital scrapped
        mc_kpscrapped_us_2030 <- c(mc_kpscrapped_us_2030,sum(kp_scrapped))  #produced capital scrapped
        mc_khscrapped_us_2030 <- c(mc_khscrapped_us_2030,sum(kh_scrapped))  #human capital scrapped
        mc_kscrappedtable_us_2030 <- cbind(mc_kscrappedtable_us_2030,k_scrapped)  #table of years capital was scrapped
        
        #save highest & lowest scrapped_tables for further analysis
        if(sum(k_scrapped) == min(mc_kscrapped_us_2030)){
          low_scrappedtable_us_2030 <- scrapped_table
        }else if(sum(k_scrapped) == max(mc_kscrapped_us_2030)){
          high_scrappedtable_us_2030 <- scrapped_table
        }
        
        #add total scrapped to running totals DISCOUNTED
        mc_kscrapped_us_2030_discounted <- c(mc_kscrapped_us_2030_discounted,sum(k_scrapped_discounted))  #total capital scrapped
        mc_kpscrapped_us_2030_discounted <- c(mc_kpscrapped_us_2030_discounted,sum(kp_scrapped_discounted))  #produced capital scrapped
        mc_khscrapped_us_2030_discounted <- c(mc_khscrapped_us_2030_discounted,sum(kh_scrapped_discounted))  #human capital scrapped
        mc_kscrappedtable_us_2030_discounted <- cbind(mc_kscrappedtable_us_2030_discounted,k_scrapped_discounted)  #table of years capital was scrapped
        
        #save highest & lowest scrapped_tables for further analysis DISCOUNTED
        if(sum(k_scrapped_discounted) == min(mc_kscrapped_us_2030_discounted)){
          low_scrappedtable_us_2030_discounted <- scrapped_table
        }else if(sum(k_scrapped_discounted) == max(mc_kscrapped_us_2030_discounted)){
          high_scrappedtable_us_2030_discounted <- scrapped_table
        }
        
        #outputs
        console <- paste0("scenario = ",yearstart, " ~ ",target," (",m,") / ","sim = ",mm, " / scrapped (discounted) = ",round(sum(k_scrapped_discounted)/1000000,3), " / min = ",round(min(mc_kscrapped_us_2030_discounted)/1000000,3),", max = ",round(max(mc_kscrapped_us_2030_discounted)/1000000,3))
        full_output <- rbind(full_output,c(yearstart,target,mm,round(sum(k_scrapped_discounted)/1000000,3),round(min(mc_kscrapped_us_2030_discounted)/1000000,3),round(max(mc_kscrapped_us_2030_discounted)/1000000,3),round(min(mc_khscrapped_us_2030_discounted)/1000000,3),round(max(mc_khscrapped_us_2030_discounted)/1000000,3),round(min(mc_kpscrapped_us_2030_discounted)/1000000,3),round(max(mc_kpscrapped_us_2030_discounted)/1000000,3),round(sum(k_scrapped)/1000000,3),round(min(mc_kscrapped_us_2030)/1000000,3),round(max(mc_kscrapped_us_2030)/1000000,3),round(min(mc_khscrapped_us_2030)/1000000,3),round(max(mc_khscrapped_us_2030)/1000000,3),round(min(mc_kpscrapped_us_2030)/1000000,3),round(max(mc_kpscrapped_us_2030)/1000000,3)))
      }
      
      
      write.csv(full_output,file=paste(filepath,"us_output.csv",sep=""))
      message(console)
      flush.console()
      
    }
    
    #################### END OUTPUT ####################
    
    
  }  #next simulation
  
  
  #################### END SIMULATION ####################
  
  
  #console output
  message(paste0("~~~~~ END OF SCENARIO ",yearstart, " ~ ",target," ~~~~~")) 
  
  
}  #next scenario



################################################################################