%ILO global recruitment rate analysis
%11/12/2023
%A.Jarvis

clear all

%WORLD ILO data for last five years
M = [315607.699	695630.049	921352.658	877626.561	803571.667	786920.159	737499.421	613829.973	462738.778	291855.852	246926.023
311514.281	691568.64	917089.943	901766.937	815811.363	785694.924	746305.909	628363.509	475355.211	297571.399	255631.795
307396.356	687707.57	906965.175	924421.73	830449.224	784532.441	754230.087	642597.8	490088.251	303229.397	266865.317
306687.125	686411.195	895911.626	941233.798	846854.967	784466.629	759049.752	654655.88	504320.487	308686.945	276559.241
306251.053	684856.316	887710.127	950558.79	864987.967	788325.229	761729.992	665411.829	518206.248	315833.66	286104.115];

%average
AGE = [(17:5:62)';67];
POPmu = mean(M)';POPmu = POPmu/sum(POPmu);
POPsi = std(M)';
AGE = AGE(1:end-1);
POPmu = POPmu(1:end-1);

%normalise
POPmu = POPmu./sum(POPmu);

%extrapolate the tails
m = diff(POPmu(1:2))/diff(AGE(1:2));
c = POPmu(1)-m*AGE(1);
t0 = round(-c/m);
AGE = [(0:9)';t0;AGE];
POPmu = [zeros(10,1);0;POPmu];
t = (1:(100-AGE(end)))';
AGE = [AGE;AGE(end)+t];
POPmu = [POPmu;POPmu(end)*exp(-1*t/5)];

%Interpolate to annual data
AGEi = (min(AGE):max(AGE))';
POPmui = zeros(size(AGEi))*NaN;
for i = 1:length(AGE)
    
    j = find(AGEi==AGE(i));
    POPmui(j) = POPmu(i);
    
end

POPmui = interp1(AGE,POPmu,AGEi,'cubic');

%separate into recruitment and retirement using first difference
dPOPmui = [0;diff(POPmui)];
[dPOPmui] = irwsm(dPOPmui,0,1e0);
i = find(dPOPmui>=0);
RECi = zeros(size(AGEi));
RECi(i) = -dPOPmui(i); 
RECi = RECi/sum(RECi);cRECi = cumsum(RECi);
i = find(dPOPmui<=0);
RETi = zeros(size(AGEi));
RETi(i) = -dPOPmui(i); RETi = RETi/sum(RETi);cRETi = cumsum(RETi);

%earnings curve
f = AGEi/40-1/4;
i = find(f<0);f(i)=0;i = find(f>1);f(i) = 1;

%sample recruitment and retirement distributions to get working life distribution,
%and then apply earning curve and discounting to get human capital capital
N = 1e5;
M = length(AGEi);
KHUMAN = zeros(N,M);
RECAGE = zeros(N,M);
RETAGE = zeros(N,M);
WWLIFE = zeros(N,M);

for j = 1:length(AGEi)
    
    for i = 1:N
        
        d = find(cRECi>=rand);
        RECAGE(i,j) = AGEi(d(1));
        d = find(cRETi>=rand);
        RETAGE(i,j) = AGEi(d(1));
        WWLIFE(i,j) = RETAGE(i,j) - RECAGE(i,j);
        
        if AGEi(j)<RETAGE(i,j) && AGEi(j)>RECAGE(i,j)
            t = RETAGE(i,j)-AGEi(j);    %remaining working life for that aged person
            w = AGEi(j)+t;
            f = w/30-1/3;
            ii = find(f<0);f(ii)=0;ii = find(f>1);f(ii) = 1;
            KHUMAN(i,j) = sum(f.*exp(-0.015*(0:t)));    %time discounted NPV of all future wages from here to retirement
        else
            KHUMAN(i,j) = 0;
        end
        
    end
    
end

%aggregate in age groups
KHUMAN = sum(KHUMAN)';
KHUMAN = KHUMAN/sum(KHUMAN);
WWLIFEi = hist(WWLIFE(:,1),AGEi)';
WWLIFEi = WWLIFEi/sum(WWLIFEi);

%re-separate human capital recruitment and retirement from first difference
[KHUMANs,dKHUMAN] = irwsm(KHUMAN,1,1e2);
i = find(dKHUMAN<=0);
KHUMANRET = zeros(size(AGEi));
KHUMANRET(i) = -dKHUMAN(i);cKHUMANRET = cumsum(KHUMANRET)/sum(KHUMANRET); 
i = find(dKHUMAN>=0);
KHUMANREC = zeros(size(AGEi));
KHUMANREC(i) = dKHUMAN(i);cKHUMANREC = cumsum(KHUMANREC)/sum(KHUMANREC); 

%resample capital recruitment and retirement distributions to get capital working life distribution,
N = 1e5;
RECAGE = zeros(N,1);
RETAGE = zeros(N,1);
KSLIFE = zeros(N,1);

for i = 1:N
        
        d = find(cKHUMANREC>=rand);
        RECAGE(i) = AGEi(d(1));
        d = find(cKHUMANRET>=rand);
        RETAGE(i) = AGEi(d(1));
        if RETAGE(i) < RECAGE(i)     
           KSLIFE(i) = NaN;
        else
            KSLIFE(i) = RETAGE(i) - RECAGE(i);
        end
        
end

%and collect together
[RECAGEi] = hist(RECAGE,AGEi)';RECAGEi = RECAGEi/sum(RECAGEi);
[RETAGEi] = hist(RETAGE,AGEi)';RETAGEi = RETAGEi/sum(RETAGEi);
[KSLIFEi] = hist(KSLIFE,AGEi)';KSLIFEi = KSLIFEi/sum(KSLIFEi);

%and plot
figure(2);clf
pbaspect([1 .5 1])
set(gcf,'pos',[1 1 800 800])
set(gca,'pos',[0.15    0.15    0.75    0.75/2])

hold on
plot(AGEi,KHUMAN*100,'k')

plot(AGEi,100*POPmui*max(KHUMAN)/max(POPmui),'k--')

d1 = patch([AGEi;flipud(AGEi)],[KHUMANREC;zeros(size(KHUMANREC))]*1000,[1 1 1]);
set(d1,'facecolor',[0 1 0]*.5,'edgecolor',[0 1 0]*.5,'facealpha',0.35,'edgealpha',0.35);

d1 = patch([AGEi;flipud(AGEi)],[KHUMANRET;zeros(size(KHUMANRET))]*1000,[1 1 1]);
set(d1,'facecolor',[1 0 0]*.5,'edgecolor',[1 0 0]*.5,'facealpha',0.35,'edgealpha',0.35);

%d1 = patch([AGEi;flipud(AGEi)],[KSLIFEi;zeros(size(KSLIFEi))]*100,[1 1 1]);
%set(d1,'facecolor',[1 1 1]*.5,'edgecolor',[1 1 1]*.5,'facealpha',0.65,'edgealpha',0.65);

hold off
flab = gca;
xmin = 0;xmax = 100;xinc = 10;
ymin = 0;ymax = 5;yinc = 1;
flab.XTick = [xmin:xinc:xmax];
flab.XTickLabel = [xmin:xinc:xmax];
flab.YTick = [ymin:yinc:ymax];
flab.YTickLabel = [ymin:yinc:ymax];
flab.XMinorTick = 'on'
flab.YMinorTick = 'on'
xtickformat('%.0f')
ytickformat('%.0f')
flab.FontSize = 30;
flab.FontName = 'corbel light';
xlabel('age (years)','fontsize',30,'fontname','corbel light')
ylabel('proportion of human capital (%)','fontsize',30,'fontname','corbel light')
box('on')
axis([xmin xmax ymin ymax])

save Global_human_capital_service_life AGEi KSLIFEi WWLIFEi

return




